@@ -12,6 +12,13 @@ def get_resource(url):
     Issue a GET request to R25 with the given url
     and return a response as an etree element.
     """
+
+    instance = R25_DAO().get_service_setting('INSTANCE')
+    if instance is not None:
+        url = "/r25ws/wrd/{}/run/{}".format(instance, url)
+    else:
+        url = "/r25ws/servlet/wrd/run/{}".format(url)
+
     response = R25_DAO().getURL(url, {"Accept": "text/xml"})
     if response.status != 200:
         raise DataFailureException(url, response.status, response.data)
